| Title: | Kinase INteraction NETwork Generation |
|---|---|
| Description: | This package provides the functionality to process PamGene's PamChip Data Output and generate kinase interaction networks from that. This project uses a bayesian algorithm to generate bayesian networks for defining dependence relationships between peptide sequences in the PamChip data. It then uses a novel kinase assignment method to assign upstream kinases to each peptide which is then output as a graph. |
| Authors: | Ali Sajid Imami [aut, cre] (ORCID: <https://orcid.org/0000-0003-3684-3539>), Khaled Alganem [aut] (ORCID: <https://orcid.org/0000-0003-3234-7669>), Justin Fortune Creeden [aut] (ORCID: <https://orcid.org/0000-0003-3123-8401>), Alex Joyce [aut] (ORCID: <https://orcid.org/0000-0003-0303-2481>) |
| Maintainer: | Ali Sajid Imami <[email protected]> |
| License: | GPL (>= 3) | file LICENSE |
| Version: | 0.4.0.9002 |
| Built: | 2026-05-26 10:01:44 UTC |
| Source: | https://github.com/CogDisResLab/KINNET |
Assign kinases, given a network and a chip type
assign_kinases(network, chiptype, identifier = "Gene_Symbol")assign_kinases(network, chiptype, identifier = "Gene_Symbol")
network |
A network output from bnlearn |
chiptype |
Either PTK or STK |
identifier |
The identifier to use in outputs. Can be either "Gene_Symbol" or "Kinase" |
A dataframe with upstream kinases assigned to the peptide
TRUETRUE
Assign kinases, given a network and a chip type and additional essential kinases
assign_kinases_guided( network, chiptype, identifier = "Gene_Symbol", guided = NULL )assign_kinases_guided( network, chiptype, identifier = "Gene_Symbol", guided = NULL )
network |
A network output from bnlearn |
chiptype |
Either PTK or STK |
identifier |
The identifier to use in outputs. Can be either "Gene_Symbol" or "Kinase" |
guided |
A vector of Kinases or Gene_Symbols that must be included in the network. The vector must be aligned with what was specified in _identifier_ |
A dataframe with upstream kinases assigned to the peptide
TRUETRUE
Generate Candidate Kinases Based On Links
candidate_kinases(peptide, arcs, assigned_kinases)candidate_kinases(peptide, arcs, assigned_kinases)
peptide |
Peptide ID |
arcs |
The arcs in the network |
assigned_kinases |
The candidate kinases |
common kinases
TRUETRUE
This functions takes two given graphs and compares them to see the changes from one to the other
compare_kinased_graphs( reference, comparison, ref_name = "Reference", comp_name = "Comparison", render = FALSE )compare_kinased_graphs( reference, comparison, ref_name = "Reference", comp_name = "Comparison", render = FALSE )
reference |
The reference network output from assign_kinases() |
comparison |
The comparison network output from assign_kinases() |
ref_name |
Name for the reference network |
comp_name |
Name for the comparison network |
render |
logical. Whether a graph should be rendered or not. |
A graph object
TRUETRUE
Equalize the nodesets of two kinased graphs
equalize_kinase_graphs(reference, comparison)equalize_kinase_graphs(reference, comparison)
reference |
a reference result from assign_kinases() |
comparison |
a comparison result from assign_kinases() |
A list with two elements, reference and comparison, that have the same nodesets
TRUETRUE
Return a list of significant peptides
filter_peptides(chipdata, threshold = 0.75)filter_peptides(chipdata, threshold = 0.75)
chipdata |
an object of class PamchipSTK or PamchipPTK |
threshold |
a lower cutoff for significance |
a list of significant peptides for each class
TRUETRUE
Do a standardized fit of expression data from a single peptide's activity
fit_standardized(expr)fit_standardized(expr)
expr |
a dataframe containing the activity data of only one peptide |
a list of three items std_10, std_50 and std_200, of standardized linear coefficients
TRUETRUE
Generate Intersections between kinases
get_intersections(row, column, assigned_kinases)get_intersections(row, column, assigned_kinases)
row |
row peptide |
column |
column peptide |
assigned_kinases |
Kinases assigned |
common kinases beween the two groups
TRUETRUE
Calculate the Hamming Distance between two kinased graphs
kinnet_hamming(reference, comparison)kinnet_hamming(reference, comparison)
reference |
a reference result from assign_kinases() |
comparison |
a comparison result from assign_kinases() |
A positive integer
TRUETRUE
Calculate Normalized Hamming Distance
kinnet_normalized_hamming(reference, comparison)kinnet_normalized_hamming(reference, comparison)
reference |
a reference result from assign_kinases() |
comparison |
a reference result from assign_kinases() |
A positive integer
TRUETRUE
Calculate Normalized Structural Hamming Distance
kinnet_normalized_shd(reference, comparison)kinnet_normalized_shd(reference, comparison)
reference |
a reference result from assign_kinases() |
comparison |
a comparison result from assign_kinases() |
A positive integer
TRUETRUE
Calculate the Structural Hamming Distance between two kinased graphs
kinnet_shd(reference, comparison)kinnet_shd(reference, comparison)
reference |
a reference result from assign_kinases() |
comparison |
a comparison result from assign_kinases() |
A positive integer
TRUETRUE
Generate a bayes net model
make_model(expression, iterations = 200, threshold = NULL, cluster = NULL)make_model(expression, iterations = 200, threshold = NULL, cluster = NULL)
expression |
tbl_df. A tibble with the activity data from the kinome chip. |
iterations |
numeric. Number of iterations to run the mode. |
threshold |
numeric. Threshold to use for averaging the network |
cluster |
cluster. (Optional) a cluster from the package parallel |
A list with the strength network dataframe, an averaged network and the threshold used to generate that averaged network.
TRUETRUE
Process a file into a usable structure
PamchipData_PTK(dataset)PamchipData_PTK(dataset)
dataset |
character. Path to a file that holds the output of BioNavigator |
An object of class PamchipData-PTK
TRUETRUE
Process a file into a usable structure
PamchipData_STK(dataset)PamchipData_STK(dataset)
dataset |
character. Path to a file that holds the output of BioNavigator |
An object of class PamchipData-STK
TRUETRUE
The Pamchip Data Superclass
an object of class PamchipData
chip_typecharacter. A string
TRUETRUE
A representation of the PamChip PTK Data
An object of class PamchipData-PTK
BioNavigatorVersioncharacter. A string indicating the version of BioNavigator that generated the dataset
ImageAnalysisDatecharacter. The date the analysis was conducted on.
PamGridVersioncharacter. PamGrid version the chip was run on.
QuantitationTypecharacter. The kind of qunatitation analysis performed.
SampleDatatbl_df. A tibble with the observed activity on each peptide
SampleCharacteristicstbl_df. A tibble with the characteristics of each sample
RefDatatbl_df.
PeptideIDscharacter.
ProcessedDatatbl_df.
DataProcessDatecharacter. The date when the data was processed
TRUETRUE
A representation of the PamChip STK Data
An object of class PamchipData-STK
BioNavigatorVersioncharacter. A string indicating the version of BioNavigator that generated the dataset
ImageAnalysisDatecharacter. The date the analysis was conducted on.
PamGridVersioncharacter. PamGrid version the chip was run on.
QuantitationTypecharacter. The kind of qunatitation analysis performed.
SampleDatatbl_df. A tibble with the observed activity on each peptide
SampleCharacteristicstbl_df. A tibble with the characteristics of each sample
RefDatatbl_df.
PositiveControlDatatbl_df.
PeptideIDscharacter.
DataProcessDatecharacter. The date when the data was processed
TRUETRUE
A dataframe with the Bayesian posteriors of finding a given peptide/kinase pair
ptk_probability_matrix_geneptk_probability_matrix_gene
A dataframe with 991 rows and 3 columns
The peptide ID
Gene Symbol of the kinase
Posterior probability of the pair
A dataframe with the Bayesian posteriors of finding a given peptide/kinase pair
ptk_probability_matrix_kinaseptk_probability_matrix_kinase
A dataframe with 991 rows and 3 columns
The peptide ID
Gene Symbol of the kinase
Posterior probability of the pair
Generate a kianse graph
render_kinased_graph(analysis_result, title, render = FALSE)render_kinased_graph(analysis_result, title, render = FALSE)
analysis_result |
Object output from assign_kinases() |
title |
Title of the graph |
render |
logical. Whether a graph should be rendered or not. |
a graph object
TRUETRUE
Generate a reduced kianse graph
render_reduced_kinased_graph(analysis_result, title, render = FALSE)render_reduced_kinased_graph(analysis_result, title, render = FALSE)
analysis_result |
Object output from assign_kinases() |
title |
Title of the graph |
render |
logical. Whether a graph should be rendered or not. |
a graph object
TRUETRUE
This function takes a bn object and a node and adds it if it's not already in the nodeset.
safely_add_node(net, node)safely_add_node(net, node)
net |
A bn object |
node |
A node label |
A bn object with the node added
TRUETRUE
These functions provide a variety of data setters and getter for the Pamchip objects.
pheno_data(chipdata, ...) ## S4 method for signature ''PamchipData-STK'' pheno_data(chipdata) exp_data(chipdata, ...) ## S4 method for signature ''PamchipData-STK'' exp_data(chipdata) classes(chipdata, ...) ## S4 method for signature ''PamchipData-STK'' classes(chipdata) peptides(chipdata, ...) ## S4 method for signature ''PamchipData-STK'' peptides(chipdata)pheno_data(chipdata, ...) ## S4 method for signature ''PamchipData-STK'' pheno_data(chipdata) exp_data(chipdata, ...) ## S4 method for signature ''PamchipData-STK'' exp_data(chipdata) classes(chipdata, ...) ## S4 method for signature ''PamchipData-STK'' classes(chipdata) peptides(chipdata, ...) ## S4 method for signature ''PamchipData-STK'' peptides(chipdata)
chipdata |
an object of class PamchipData-STK or PamchipData-PTK |
... |
Currently unused |
These functions allow you to get and set the slots of the object.
processed_data accesses the processed and transformed data
pheno_data gives the sample characteristics
exp_data access the actual intensity values
classes gives the unique classes in the chip
peptides gives the reference list of peptides on the chip
The requested object
A dataframe with the Bayesian posteriors of finding a given peptide/kinase pair
stk_probability_matrix_genestk_probability_matrix_gene
A dataframe with 10428 rows and 3 columns
The peptide ID
Gene Symbol of the kinase
Posterior probability of the pair
A dataframe with the Bayesian posteriors of finding a given peptide/kinase pair
stk_probability_matrix_kinasestk_probability_matrix_kinase
A dataframe with 10428 rows and 3 columns
The peptide ID
Gene Symbol of the kinase
Posterior probability of the pair
Subset the Kinome data to a given list of peptides and conditions
subset_data(chipdata, peptides, class)subset_data(chipdata, peptides, class)
chipdata |
Pamchip-PTK. A Pamchip-PTK Object with all the data available |
peptides |
character. A vector of peptides of interest |
class |
character. A specification of the sample class you want to filter to |
A tibble with the filtered and asinh transformed data
TRUETRUE
Calculated Updated Probabilities of each peptide/kinase pair
update_probability_matrix( chiptype, assignment_df, identifier = "Gene_Symbol", guided = NULL )update_probability_matrix( chiptype, assignment_df, identifier = "Gene_Symbol", guided = NULL )
chiptype |
character. Either "STK" or "PTK" |
assignment_df |
tbl_df. A tibble with the potential kianse assignments |
identifier |
The identifier to use in outputs. Can be either "Gene_Symbol" or "Kinase" |
guided |
A vector of Kinases or Gene_Symbols that must be included in the network. The vector must be aligned with what was specified in _identifier_ |
an updated dataframe with the probabilities
TRUETRUE